@@ -10,13 +10,15 @@ import pickle
 from collections import defaultdict
 import numpy as np
 from scipy.spatial import cKDTree
-from zort.radec import lightcurve_file_is_pole
+from zort.radec import return_shifted_ra
 
 
 def generate_objects_file(lightcurve_file):
     objects_file = lightcurve_file.replace('.txt', '.objects')
-    if os.path.exists(objects_file):
-        print('%s already exists. Skipping.' % objects_file)
+    objects_map_file = lightcurve_file.replace('.txt', '.objects_map')
+
+    if os.path.exists(objects_file) and os.path.exists(objects_map_file):
+        print('%s and %s already exists. Skipping.' % (objects_file, objects_map_file))
         return
 
     f_in = open(lightcurve_file, 'r')
@@ -47,15 +49,22 @@ def generate_objects_file(lightcurve_file):
 
     f_in.close()
 
-    objects_file = lightcurve_file.replace('.txt', '.objects_map')
-    with open(objects_file, 'wb') as fileObj:
+    with open(objects_map_file, 'wb') as fileObj:
         pickle.dump(object_map, fileObj)
 
 
-def save_radec_map(DR1_object_file, radec_map):
-    radec_map_filename = DR1_object_file.replace('.objects', '.radec_map')
-    with open(radec_map_filename, 'wb') as fileObj:
-        pickle.dump(radec_map, fileObj)
+def save_radec_map(lightcurve_file, radec_map):
+    _save_map(lightcurve_file, radec_map, 'radec_map')
+    
+    
+def save_rcid_map(lightcurve_file, rcid_map):
+    _save_map(lightcurve_file, rcid_map, 'rcid_map')
+
+
+def _save_map(lightcurve_file, map, extension):
+    map_filename = lightcurve_file.replace('txt', extension)
+    with open(map_filename, 'wb') as fileObj:
+        pickle.dump(map, fileObj)
 
 
 def return_radec_map_size(radec_map):
@@ -73,10 +82,12 @@ def return_radec_map_filesize(radec_map):
     return radec_map_filesize
 
 
-def generate_radec_map(lightcurve_file):
+def generate_radec_rcid_maps(lightcurve_file):
     radec_map_file = lightcurve_file.replace('.txt', '.radec_map')
-    if os.path.exists(radec_map_file):
-        print('%s already exists. Skipping.' % radec_map_file)
+    rcid_map_file = lightcurve_file.replace('.txt', '.rcid_map')
+
+    if os.path.exists(radec_map_file) and os.path.exists(rcid_map_file):
+        print('%s and already exists. Skipping.' % (radec_map_file, rcid_map_file))
         return
 
     objects_file = lightcurve_file.replace('.txt', '.objects')
@@ -88,10 +99,18 @@ def generate_radec_map(lightcurve_file):
     filterid, filterid_current = None, None
     ra_arr, dec_arr, object_id_arr = [], [], []
     radec_map = defaultdict(dict)
+    object_location_start = None
+    rcid_map = defaultdict(dict)
+    field_id = int(lightcurve_file.split('_')[0].replace('field', ''))
 
-    is_pole = lightcurve_file_is_pole(lightcurve_file)
+    while True:
+        line = f_in.readline()
+        object_location_current = f_in.tell() - len(line)
+
+        # Check for end of the file
+        if not line:
+            break
 
-    for line in f_in:
         data = line.replace('\n', '').split(',')
 
         object_id = int(data[0])
@@ -100,28 +119,40 @@ def generate_radec_map(lightcurve_file):
 
         # Initialize the rcid
         if rcid_current is None:
+            object_location_start = object_location_current
             rcid_current = rcid
             filterid_current = filterid
 
         # Check to see if the block has switched
         if rcid != rcid_current:
+            # set bounds of rcid
+            rcid_map[filterid_current][rcid_current] = (
+                object_location_start, object_location_current)
+            object_location_start = object_location_current
+
+            # build kdtree for rcid
             objects = np.array([ra_arr, dec_arr]).T
             kdtree = cKDTree(objects)
             radec_map[filterid_current][rcid_current] = \
                 (kdtree, object_id_arr)
 
+            # update rcid and filter for new region
             rcid_current = rcid
             filterid_current = filterid
             ra_arr, dec_arr, object_id_arr = [], [], []
 
         ra, dec = float(data[5]), float(data[6])
-        if is_pole and ra > 180:
-            ra -= 360
+        ra_obj = return_shifted_ra(ra, field_id)
 
-        ra_arr.append(ra)
+        ra_arr.append(ra_obj)
         dec_arr.append(dec)
         object_id_arr.append(object_id)
 
+    # update rcid_map with final rcid
+    rcid_map[filterid_current][rcid_current] = (
+        object_location_start, object_location_current)
+
+    # build kdtree for final rcid
     objects = np.array([ra_arr, dec_arr]).T
     kdtree = cKDTree(objects)
     radec_map[filterid_current][rcid_current] = \
@@ -129,4 +160,5 @@ def generate_radec_map(lightcurve_file):
 
     f_in.close()
 
-    save_radec_map(radec_map_file, radec_map)
+    save_radec_map(lightcurve_file, radec_map)
+    save_rcid_map(lightcurve_file, rcid_map)
